import { getReduxWrapperWithStore } from '@/utils/testing/getReduxWrapperWithStore';
import { StoreType } from '@/redux/store';
import { fireEvent, render, screen } from '@testing-library/react';
import { SearchBar } from './SearchBar.component';

const renderComponent = (): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore();

  return (
    render(
      <Wrapper>
        <SearchBar />
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('SearchBar - component', () => {
  it('should let user type text', () => {
    renderComponent();
    const input = screen.getByTestId<HTMLInputElement>('search-input');

    fireEvent.change(input, { target: { value: 'test value' } });

    expect(input.value).toBe('test value');
  });

  it('should disable button when the user clicks the lens button', () => {
    renderComponent();
    const input = screen.getByTestId<HTMLInputElement>('search-input');

    fireEvent.change(input, { target: { value: 'park7' } });

    const button = screen.getByRole('button');

    fireEvent.click(button);

    expect(button).toBeDisabled();
  });

  it('should disable input when the user clicks the Enter', () => {
    renderComponent();
    const input = screen.getByTestId<HTMLInputElement>('search-input');

    fireEvent.change(input, { target: { value: 'park7' } });
    fireEvent.keyDown(input, { key: 'Enter', code: 'Enter', charCode: 13 });

    expect(input).toBeDisabled();
  });
});
