import bioEntityContentsReducer from '@/redux/bioEntityContents/bioEntityContents.slice';
import chemicalsReducer from '@/redux/chemicals/chemicals.slice';
import drawerReducer from '@/redux/drawer/drawer.slice';
import drugsReducer from '@/redux/drugs/drugs.slice';
import mirnasReducer from '@/redux/mirnas/mirnas.slice';
import modelsReducer from '@/redux/models/models.slice';
import projectReducer from '@/redux/project/project.slice';
import searchReducer from '@/redux/search/search.slice';
import { RootState, StoreType } from '@/redux/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';

interface WrapperProps {
  children: React.ReactNode;
}

export type InitialStoreState = Partial<RootState>;

type GetReduxWrapperUsingSliceReducer = (initialState?: InitialStoreState) => {
  Wrapper: ({ children }: WrapperProps) => JSX.Element;
  store: StoreType;
};

export const getReduxWrapperWithStore: GetReduxWrapperUsingSliceReducer = (
  preloadedState: InitialStoreState = {},
) => {
  const testStore = configureStore({
    reducer: {
      search: searchReducer,
      project: projectReducer,
      drugs: drugsReducer,
      mirnas: mirnasReducer,
      chemicals: chemicalsReducer,
      bioEntityContents: bioEntityContentsReducer,
      drawer: drawerReducer,
      models: modelsReducer,
    },
    preloadedState,
  });

  const Wrapper = ({ children }: WrapperProps): JSX.Element => (
    <Provider store={testStore}>{children}</Provider>
  );

  return { Wrapper, store: testStore };
};
